@@ -1,4 +1,4 @@
-# $Id: Directory.pm 41227 2014-03-26 13:47:17Z anton $
+# $Id: Directory.pm 41443 2014-04-30 09:39:57Z anton $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/pwdmodifier/libpwdmodifier/lib/UvT/PwdModifier/Directory.pm $
 
 use strict;
@@ -90,8 +90,15 @@ sub stuff {
         mail
         mailhost
         passwordExpirationStage
-        passwordExpirationStageTime
         passwordExpirationFinalDay
+        passwordExpirationAttention
+        passwordExpirationWarning
+        passwordExpirationReminder
+        passwordExpirationLastReminder
+        passwordExpirationExpired
+        passwordExpirationAdminRequired
+        passwordChangeCount
+        passwordChangeDate
         passwordStatus
         privateEmail
         rcryptPassword
@@ -420,12 +427,13 @@ sub getRcryptPassword {
 
 sub toggleAccountState {
 	my ($attrib, $uid, $on, $label, $by) = @_;
+	# ignore label
 	my ($entry, $ldap) = $self->getEntryByUID($uid);
 
 	if ($on) {
 		my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
 		$year += 1900; $mday +=1 ;
-		my $content = sprintf("$label at: $year-%02d-%02d %02d:%02d $by", $mon, $mday, $hour,$min);
+		my $content = sprintf("$year-%02d-%02d %02d:%02d $by", $mon, $mday, $hour,$min);
 		$entry->replace($attrib, $content);
 	} else {
 		$entry->delete($attrib);
@@ -441,6 +449,7 @@ sub toggleAccountState {
 
 sub replaceAttribute {
 	my ($uid, $attrib, $value) = @_;
+#	warn "replaceAttribute; uid: $uid, attrib: \"$attrib\", value: \"$value\"";
 	my ($entry, $ldap) = $self->getEntryByUID($uid);
 	if (defined($value)) {
 		$entry->replace($attrib, $value);
